pyprofit
########

.. image:: https://travis-ci.org/ICRAR/pyprofit.svg?branch=master
    :target: https://travis-ci.org/ICRAR/pyprofit

.. image:: https://img.shields.io/pypi/v/pyprofit.svg
    :target: https://pypi.python.org/pypi/pyprofit

.. image:: https://img.shields.io/pypi/pyversions/pyprofit.svg
    :target: https://pypi.python.org/pypi/pyprofit

*pyprofit* is a python wrapper for `libprofit <https://www.github.com/ICRAR/libprofit>`_.
As such, you need to have *libprofit* installed in your system to install
*pyprofit*.
For instruction on how to compile and instal *libprofit* please read
`libprofit's documentation <http://libprofit.readthedocs.io/en/latest/getting.html#compiling>`_.

*pyprofit* is available in `PyPI <https://pypi.python.org/pypi/pyprofit>`_
and thus can be easily installed via::

 pip install pyprofit

If you need to point to a specific libprofit installation
set the ``LIBPROFIT_HOME`` environment variable to point to it,
e.g.::

 LIBPROFIT_HOME=/opt/software/libprofit/1.8.0/ pip install pyprofit
